==> nextcloud-26.0.11p1.tgz: nextcloud/apps/viewer/l10n/en_GB.js <==
OC.L10N.register(
    "viewer",
    {
    "Viewer" : "Viewer",
    "Simple file viewer with slideshow for media" : "Simple file viewer with slideshow for media",
    "Show your latest holiday photos and videos like in the movies, show a glimpse of your latest novel directly from your Nextcloud, choose the best GIF of your collection thanks to the direct preview of your favorites files and many more!" : "Show your latest holiday photos and videos like in the movies, show a glimpse of your latest novel directly from your Nextcloud, choose the best GIF of your collection thanks to the direct preview of your favorites files and many more!",
    "Your browser does not support audio." : "Your browser does not support audio.",
    "Error loading {name}" : "Error loading {name}",
    "Image saved" : "Image saved",
    "Error saving image" : "Error saving image",
    "Unsaved changes" : "Unsaved changes",
    "Drop changes" : "Drop changes",
    "Play the live photo" : "Play the live photo",
    "LIVE" : "LIVE",
    "Your browser does not support videos." : "Your browser does not support videos.",
    "Edit" : "Edit",
    "Exit full screen" : "Exit full screen",
    "Full screen" : "Full screen",
    "Open sidebar" : "Open sidebar",
    "Download" : "Download",
    "Delete" : "Delete",
    "This file no longer exists" : "This file no longer exists",
    "There is no plugin available to display this file type" : "There is no plugin available to display this file type",
    "View" : "View",
    "Name" : "Surname",
    "Save" : "Save",
    "Save as" : "Save as",
    "Back" : "Back",
    "Loading …" : "Loading …",
    "Reset" : "Reset",
    "All changes will be lost." : "All changes will be lost.",
    "Are you sure you want to continue?" : "Are you sure you want to continue?",
    "Cancel" : "Cancel",
    "Continue" : "Continue",
    "Undo" : "Undo",
    "Redo" : "Redo",
    "Show original image" : "Show original image",
    "Zoom in" : "Zoom in",
    "Zoom out" : "Zoom out",
    "Toggle zoom menu" : "Toggle zoom menu",
    "Adjust" : "Adjust",
    "Fine-tune" : "Fine-tune",
    "Filters" : "Filters",
    "Watermark" : "Watermark",
    "Draw" : "Draw",
    "Resize" : "Resize",
    "Invalid image." : "Invalid image.",
    "Error while uploading the image." : "Error while uploading the image.",
    "are not images" : "are not images",
    "is not an image" : "is not an image",
    "to be uploaded" : "to be uploaded",
    "Crop" : "Crop",
    "Original" : "Original",
    "Custom" : "Custom",
    "Square" : "Square",
    "Landscape" : "Landscape",
    "Portrait" : "Portrait",
    "Ellipse" : "Ellipse",
    "Classic TV" : "Classic TV",
    "CinemaScope" : "CinemaScope",
    "Arrow" : "Arrow",
    "Blur" : "Blur",
    "Brightness" : "Brightness",
    "Contrast" : "Contrast",
    "Un-flip X" : "Un-flip X",
    "Flip X" : "Flip X",
    "Un-flip Y" : "Un-flip Y",
    "Flip Y" : "Flip Y",
    "HSV" : "HSV",
    "Hue" : "Hue",
    "Saturation" : "Saturation",
    "Value" : "Value",
    "Image" : "Image",
    "Importing …" : "Importing …",
    "+ Add image" : "+ Add image",
    "Line" : "Line",
    "Pen" : "Pen",
    "Polygon" : "Polygon",
    "Sides" : "Sides",
    "Rectangle" : "Rectangle",
    "Corner Radius" : "Corner Radius",
    "Width in pixels" : "Width in pixels",
    "Height in pixels" : "Height in pixels",
    "Toggle ratio lock" : "Toggle ratio lock",
    "Reset to original image size" : "Reset to original image size",
    "Rotate" : "Rotate",
    "Text" : "Text",
    "Text spacing" : "Text spacing",
    "Text alignment" : "Text alignment",
    "Font family" : "Font family",
    "Size" : "Size",
    "Letter spacing" : "Letter spacing",
    "Line height" : "Line height",
    "Warmth" : "Warmth",
    "+ Add watermark" : "+ Add watermark",
    "Choose watermark type" : "Choose watermark type",
    "Upload watermark" : "Upload watermark",
    "Add as text" : "Add as text",
    "Padding" : "Padding",
    "Shadow" : "Shadow",
    "Horizontal" : "Horizontal",
    "Vertical" : "Vertical",
    "Opacity" : "Opacity",
    "Position" : "Position",
    "Stroke" : "Stroke",
    "Save image as" : "Save image as",
    "Extension" : "Extension",
    "Name is required." : "Name is required.",
    "Quality" : "Quality",
    "Saved image size (width x height)" : "Saved image size (width x height)",
    "Note that the selected crop area is lower than the applied resize which might cause quality decrease" : "Note that the selected crop area is lower than the applied resize which might cause quality decrease",
    "Actual size (100%)" : "Actual size (100%)",
    "Fit size" : "Fit size",
    "\"{fileName}\"" : "\"{fileName}\""
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-27.1.11.tgz: nextcloud/apps/viewer/l10n/en_GB.js <==
OC.L10N.register(
    "viewer",
    {
    "Viewer" : "Viewer",
    "Simple file viewer with slideshow for media" : "Simple file viewer with slideshow for media",
    "Show your latest holiday photos and videos like in the movies, show a glimpse of your latest novel directly from your Nextcloud, choose the best GIF of your collection thanks to the direct preview of your favorites files and many more!" : "Show your latest holiday photos and videos like in the movies, show a glimpse of your latest novel directly from your Nextcloud, choose the best GIF of your collection thanks to the direct preview of your favourites files and many more!",
    "Your browser does not support audio." : "Your browser does not support audio.",
    "Error loading {name}" : "Error loading {name}",
    "Image saved" : "Image saved",
    "Error saving image" : "Error saving image",
    "Unsaved changes" : "Unsaved changes",
    "Drop changes" : "Drop changes",
    "Play the live photo" : "Play the live photo",
    "LIVE" : "LIVE",
    "Your browser does not support videos." : "Your browser does not support videos.",
    "Edit" : "Edit",
    "Exit full screen" : "Exit full screen",
    "Full screen" : "Full screen",
    "Open sidebar" : "Open sidebar",
    "Download" : "Download",
    "Delete" : "Delete",
    "This file no longer exists" : "This file no longer exists",
    "There is no plugin available to display this file type" : "There is no plugin available to display this file type",
    "View" : "View",
    "Name" : "Surname",
    "Save" : "Save",
    "Save as" : "Save as",
    "Back" : "Back",
    "Loading …" : "Loading …",
    "Reset" : "Reset",
    "All changes will be lost." : "All changes will be lost.",
    "Are you sure you want to continue?" : "Are you sure you want to continue?",
    "Cancel" : "Cancel",
    "Continue" : "Continue",
    "Undo" : "Undo",
    "Redo" : "Redo",
    "Show original image" : "Show original image",
    "Zoom in" : "Zoom in",
    "Zoom out" : "Zoom out",
    "Toggle zoom menu" : "Toggle zoom menu",
    "Adjust" : "Adjust",
    "Fine-tune" : "Fine-tune",
    "Filters" : "Filters",
    "Watermark" : "Watermark",
    "Draw" : "Draw",
    "Resize" : "Resize",
    "Invalid image." : "Invalid image.",
    "Error while uploading the image." : "Error while uploading the image.",
    "are not images" : "are not images",
    "is not an image" : "is not an image",
    "to be uploaded" : "to be uploaded",
    "Crop" : "Crop",
    "Original" : "Original",
    "Custom" : "Custom",
    "Square" : "Square",
    "Landscape" : "Landscape",
    "Portrait" : "Portrait",
    "Ellipse" : "Ellipse",
    "Classic TV" : "Classic TV",
    "CinemaScope" : "CinemaScope",
    "Arrow" : "Arrow",
    "Blur" : "Blur",
    "Brightness" : "Brightness",
    "Contrast" : "Contrast",
    "Un-flip X" : "Un-flip X",
    "Flip X" : "Flip X",
    "Un-flip Y" : "Un-flip Y",
    "Flip Y" : "Flip Y",
    "HSV" : "HSV",
    "Hue" : "Hue",
    "Saturation" : "Saturation",
    "Value" : "Value",
    "Image" : "Image",
    "Importing …" : "Importing …",
    "+ Add image" : "+ Add image",
    "Line" : "Line",
    "Pen" : "Pen",
    "Polygon" : "Polygon",
    "Sides" : "Sides",
    "Rectangle" : "Rectangle",
    "Corner Radius" : "Corner Radius",
    "Width in pixels" : "Width in pixels",
    "Height in pixels" : "Height in pixels",
    "Toggle ratio lock" : "Toggle ratio lock",
    "Reset to original image size" : "Reset to original image size",
    "Rotate" : "Rotate",
    "Text" : "Text",
    "Text spacing" : "Text spacing",
    "Text alignment" : "Text alignment",
    "Font family" : "Font family",
    "Size" : "Size",
    "Letter spacing" : "Letter spacing",
    "Line height" : "Line height",
    "Warmth" : "Warmth",
    "+ Add watermark" : "+ Add watermark",
    "Choose watermark type" : "Choose watermark type",
    "Upload watermark" : "Upload watermark",
    "Add as text" : "Add as text",
    "Padding" : "Padding",
    "Shadow" : "Shadow",
    "Horizontal" : "Horizontal",
    "Vertical" : "Vertical",
    "Opacity" : "Opacity",
    "Position" : "Position",
    "Stroke" : "Stroke",
    "Save image as" : "Save image as",
    "Extension" : "Extension",
    "Name is required." : "Name is required.",
    "Quality" : "Quality",
    "Saved image size (width x height)" : "Saved image size (width x height)",
    "Note that the selected crop area is lower than the applied resize which might cause quality decrease" : "Note that the selected crop area is lower than the applied resize which might cause quality decrease",
    "Actual size (100%)" : "Actual size (100%)",
    "Fit size" : "Fit size",
    "\"{fileName}\"" : "\"{fileName}\""
},
"nplurals=2; plural=(n != 1);");
